import urllib.parse
import requests

def validate_config(config):
    """
    Validates the configuration dictionary to ensure required keys and correct data structure.
    """
    required_keys = ["return_url", "params", "platform"]
    for key in required_keys:
        if key not in config:
            raise ValueError(f"Missing required key: {key}")
    
    if "platform" not in config or not isinstance(config["platform"], dict):
        raise ValueError("Platform configuration must be a dictionary containing 'android' and 'ios' settings")
    
    if "android" not in config["platform"] or "ios" not in config["platform"]:
        raise ValueError("Both android and ios platform configurations are required")
    
    return True

def shorten_url(long_url):
    """
    Shortens a URL using the is.gd service.
    """
    try:
        response = requests.get(f"https://is.gd/create.php?format=simple&url={urllib.parse.quote(long_url)}")
        if response.status_code == 200:
            return response.text
        else:
            return long_url
    except Exception as e:
        print(f"Error shortening URL: {e}")
        return long_url
