import unittest
from onelink.generator import DeeplinkGenerator
from onelink.utils import validate_config, shorten_url

class TestDeeplinkPackage(unittest.TestCase):
    
    def setUp(self):
        self.config = {
            "return_url": "https://abc.com/invite_email",
            "events": "invite-email",
            "params": {
                "email": "abc@yopmail.com",
                "invite_code": "ABJGD867252JJHG%$#KLFJKLFG",
                "custom_param1": "value1",
                "custom_param2": "value2"
            },
            "platform": {
                "android": {
                    "package": "com.abcandroid",
                    "fallback_url": "https://play.google.com/store/apps/details?id=com.example.android"
                },
                "ios": {
                    "package": "com.abcios",
                    "fallback_url": "https://apps.apple.com/us/app/example/id123456789"
                }
            }
        }
        self.deeplink_generator = DeeplinkGenerator(self.config)

    def test_validate_config_valid(self):
        try:
            self.deeplink_generator.validate_config()
        except ValueError:
            self.fail("validate_config raised ValueError unexpectedly!")

    def test_generate_deeplink(self):
        deeplink = self.deeplink_generator.generate_deeplink()
        self.assertIn("https://abc.com/invite_email?", deeplink)
    
    def test_shorten_url(self):
        long_url = "https://example.com"
        short_url = shorten_url(long_url)
        self.assertTrue(short_url.startswith("http"))
        
    def test_create_deeplink(self):
        short_link = self.deeplink_generator.create_deeplink()
        self.assertTrue(short_link.startswith("http"))

if __name__ == '__main__':
    unittest.main()
